==> haskell-critbit-0.2.0.0-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-critbit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: critbit
version: 0.2.0.0
id: critbit-0.2.0.0-B6bN7Xe9Rwj9YBeXzH4nqh
key: critbit-0.2.0.0-B6bN7Xe9Rwj9YBeXzH4nqh
license: BSD-3-Clause
copyright: 2013-2014 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/critbit
synopsis: Crit-bit maps and sets
description:
    This package implements crit-bit trees, a key-value container type
    for storing keys that can be treated as bitstrings (e.g.
    '\''ByteString'\'' and '\''Text'\'').
    .
    Compared to the data structures from the containers and
    unordered-containers packages, you will find that sometimes the
    functions implemented in this package are faster, sometimes
    slower.
    .
    In many cases, a '\''CritBit'\'' tree provides performance close to that
    of a '\''HashMap'\'', while providing ordered storage and traversal
    like a '\''Map'\''.
category: Data
abi: 3a1fa1563eecf5dcfd50c5486ba6c6ed
exposed: True
exposed-modules:
    Data.CritBit.Map.Lazy Data.CritBit.Set
hidden-modules: Data.CritBit.Core Data.CritBit.Types.Internal
                Data.CritBit.Tree
import-dirs: /usr/lib/ghc-8.6.2/site-local/critbit-0.2.0.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/critbit-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/critbit-0.2.0.0
hs-libraries: HScritbit-0.2.0.0-B6bN7Xe9Rwj9YBeXzH4nqh
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 deepseq-1.4.4.0
    text-1.2.3.1 vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-critbit/html/critbit.haddock
haddock-html: /usr/share/doc/haskell-critbit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-critbit-0.2.0.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-critbit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: critbit
version: 0.2.0.0
id: critbit-0.2.0.0-Ji31gyEoXgt5W86dfAk9Bo
key: critbit-0.2.0.0-Ji31gyEoXgt5W86dfAk9Bo
license: BSD-3-Clause
copyright: 2013-2014 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/critbit
synopsis: Crit-bit maps and sets
description:
    This package implements crit-bit trees, a key-value container type
    for storing keys that can be treated as bitstrings (e.g.
    '\''ByteString'\'' and '\''Text'\'').
    .
    Compared to the data structures from the containers and
    unordered-containers packages, you will find that sometimes the
    functions implemented in this package are faster, sometimes
    slower.
    .
    In many cases, a '\''CritBit'\'' tree provides performance close to that
    of a '\''HashMap'\'', while providing ordered storage and traversal
    like a '\''Map'\''.
category: Data
abi: 93f21328718a373263b57fc65d8fd5e6
exposed: True
exposed-modules:
    Data.CritBit.Map.Lazy Data.CritBit.Set
hidden-modules: Data.CritBit.Core Data.CritBit.Types.Internal
                Data.CritBit.Tree
import-dirs: /usr/lib/ghc-8.6.3/site-local/critbit-0.2.0.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/critbit-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/critbit-0.2.0.0
hs-libraries: HScritbit-0.2.0.0-Ji31gyEoXgt5W86dfAk9Bo
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 deepseq-1.4.4.0
    text-1.2.3.1 vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-critbit/html/critbit.haddock
haddock-html: /usr/share/doc/haskell-critbit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
